@@ -117,17 +117,17 @@ sf_auth <- function(username = NULL,
   
   if(!is.null(username) & !is.null(password) & !is.null(security_token)){
     
-    deprecate_warn("1.0.1", 
-                   "salesforcer::sf_auth(security_token = )",
-                   "sf_auth(token = )",
-                   details = paste0("Beginning February 1st, 2022, Salesforce will be requiring customers ",
-                                    "to enable multi-factor authentication, which means ",
-                                    "that basic authentication using password and ",
-                                    "security token will no longer work. sf_auth() will return ",
-                                    "the error message: ",
-                                    "'INVALID_LOGIN: Invalid username, password, security token; or user locked out.'."
-                                    )
-                   )
+    # deprecate_warn("1.0.1", 
+    #                "salesforcer::sf_auth(security_token = )",
+    #                "sf_auth(token = )",
+    #                details = paste0("Beginning February 1st, 2022, Salesforce will be requiring customers ",
+    #                                 "to enable multi-factor authentication, which means ",
+    #                                 "that basic authentication using password and ",
+    #                                 "security token will no longer work. sf_auth() will return ",
+    #                                 "the error message: ",
+    #                                 "'INVALID_LOGIN: Invalid username, password, security token; or user locked out.'."
+    #                                 )
+    #                )
     
     # basic authentication (username-password) ---------------------------------
     body <- xml_new_document()
