@@ -1,5 +1,8 @@
 #' Base REST API URL Generator
 #' 
+#' @return \code{character}; a complete URL (as a string) that will be used to 
+#' send REST API calls to. This URL is specific to your instance and the API 
+#' version being used.
 #' @note This function is meant to be used internally. Only use when debugging.
 #' @keywords internal
 #' @export
@@ -14,6 +17,9 @@ make_base_rest_url <- function(){
 #' REST API Describe URL Generator
 #' 
 #' @template object_name
+#' @return \code{character}; a complete URL (as a string) that will be used to 
+#' send REST API calls to regarding a specific object. This URL is also specific 
+#' to your instance and the API version being used.
 #' @note This function is meant to be used internally. Only use when debugging.
 #' @keywords internal
 #' @export
@@ -26,21 +32,11 @@ make_rest_describe_url <- function(object_name){
           object_name)
 }
 
-#' Parameterized Search URL Generator
-#' 
-#' @importFrom xml2 url_escape
-#' @importFrom httr build_url parse_url
-#' @note This function is meant to be used internally. Only use when debugging.
-#' @keywords internal
-#' @export
-make_parameterized_search_url <- function(search_string, params){
-  this_url <- parse_url(paste0(make_base_rest_url(), "parameterizedSearch/"))
-  this_url$query <- c(list(q=url_escape(search_string)), params)
-  build_url(this_url)
-}
-
 #' Chatter Users URL Generator
 #' 
+#' @return \code{character}; a complete URL (as a string) that will be used to 
+#' send REST API calls regarding chatter users. This URL is specific to your 
+#' instance and the API version because it relies on the base rest URL.
 #' @note This function is meant to be used internally. Only use when debugging.
 #' @keywords internal
 #' @export
@@ -50,6 +46,9 @@ make_chatter_users_url <- function(){
 
 #' Composite URL Generator
 #' 
+#' @return \code{character}; a complete URL (as a string) that will be used to 
+#' send composite REST API calls to. This URL is specific to your 
+#' instance and the API version because it relies on the base rest URL.
 #' @note This function is meant to be used internally. Only use when debugging.
 #' @keywords internal
 #' @export
@@ -60,6 +59,12 @@ make_composite_url <- function(){
 #' Query URL Generator
 #' 
 #' @importFrom xml2 url_escape
+#' @template soql
+#' @template queryall
+#' @param next_records_url \code{character}; a string returned by a Salesforce 
+#' query from where to find subsequent records returned by a paginated query.
+#' @return \code{character}; a complete URL (as a string) to send a request 
+#' to in order to retrieve queried records.
 #' @note This function is meant to be used internally. Only use when debugging.
 #' @keywords internal
 #' @export
@@ -86,6 +91,13 @@ make_query_url <- function(soql, queryall, next_records_url){
 #' 
 #' @importFrom xml2 url_escape
 #' @importFrom httr build_url parse_url
+#' @param search_string \code{character}; a valid string for conducting a simple 
+#' RESTful search using parameters instead of a SOSL clause.
+#' @param params \code{list}; a list of other values to populate in the URL 
+#' query string to further restrict the search
+#' @return \code{character}; a complete URL (as a string) that has applied the 
+#' proper escaping and formatting for the search specified by the function inputs.
+#' @references \url{https://developer.salesforce.com/docs/atlas.en-us.api_rest.meta/api_rest/resources_search_parameterized.htm}
 #' @note This function is meant to be used internally. Only use when debugging.
 #' @keywords internal
 #' @export
@@ -105,6 +117,10 @@ make_parameterized_search_url <- function(search_string=NULL, params=NULL){
 #' Search URL Generator
 #' 
 #' @importFrom xml2 url_escape
+#' @param search_string \code{character}; a valid string for conducting a SOSL 
+#' search.
+#' @return \code{character}; a complete URL (as a string) that has applied the 
+#' proper escaping and formatting for the search specified by the string.
 #' @note This function is meant to be used internally. Only use when debugging.
 #' @keywords internal
 #' @export
@@ -115,24 +131,36 @@ make_search_url <- function(search_string){
 
 #' REST Objects URL Generator
 #' 
+#' @template object_name 
+#' @return \code{character}; a complete URL (as a string) that will be used to 
+#' send REST API calls to regarding a specific object. This URL is also specific 
+#' to your instance and the API version being used.
 #' @note This function is meant to be used internally. Only use when debugging.
 #' @keywords internal
 #' @export
-make_rest_objects_url <- function(object){
-  paste0(make_base_rest_url(), "sobjects/", object, "/")
+make_rest_objects_url <- function(object_name){
+  paste0(make_base_rest_url(), "sobjects/", object_name, "/")
 }
 
 #' REST Individual Record URL Generator
 #' 
+#' @template object_name
+#' @template sf_id
+#' @return \code{character}; a complete URL (as a string) that will be used to 
+#' send REST API calls to regarding a specific record in an object. This URL is 
+#' also specific to your instance and the API version being used.
 #' @note This function is meant to be used internally. Only use when debugging.
 #' @keywords internal
 #' @export
-make_rest_record_url <- function(object, sf_id){
-  paste0(make_base_rest_url(), "sobjects/", object, "/", sf_id)
+make_rest_record_url <- function(object_name, sf_id){
+  paste0(make_base_rest_url(), "sobjects/", object_name, "/", sf_id)
 }
 
 #' Composite Batch URL Generator
 #' 
+#' @return \code{character}; a complete URL (as a string) that will be used to 
+#' send composite batch REST API calls to. This URL is specific to your instance 
+#' and the API version being used because it relies on the base REST URL.
 #' @note This function is meant to be used internally. Only use when debugging.
 #' @keywords internal
 #' @export
